#!/usr/bin/python
################################################################################
#	BdsDataFile2.py		BDS API example code for a BDS DataFile access
#				T.Barnaby,	BEAM Ltd,	2012-12-19
################################################################################
#
# This Example code opens a Response file, gets information from the file.
#
import sys
import getopt
import cmath
from bdslib import *

def main():
	filename = "response.resp";

	# Create the BDS data contertor object for the data file type.
	f = DataFileResponse();

	# Open the data file
	err = f.open(filename, "r");
	if(err):
		print("Unable to open data file:", filename);
		return err;

	# Set the subformat in the file. Actually the DataFileResponse converter
	#  will performan an automatic type of file check if this is not given
	f.setFormat("RESPONSE");
	
	# Get the Metadata from the file
	(err, channelInfos, errors) = f.getMetaData(0);
	if(err):
		print("Failed to extract Ps and Zs from file ", filename, str(err));
		return err;

	print("Number of channels of info:", len(channelInfos.channels));
	for chan in channelInfos.channels:
		print("Number of segments of info:", len(chan));
		for seg in chan:
			print("Number of Responses:", len(seg.responses));
			for resp in seg.responses:
				print("Response: Stage: %d Type: %s" %(resp.stage, resp.type));
				# Print out the PoleZero response if of this type. Could also be a fap or fir response
				if(resp.type == "PoleZero"):
					for c in resp.poleZeros.poles:
						print("Pole: %f %f" % (c.real, c.imag));
					for c in resp.poleZeros.zeros:
						print("Zero: %f %f" % (c.real, c.imag));


	return 0;

if __name__ == "__main__":
	main();
